package ru.other.company.card.service.provider;

import java.io.InputStream;
import java.math.BigDecimal;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.Unmarshaller;
import org.apache.commons.lang.StringUtils;
import ru.crystals.pos.api.card.BalanceType;
import ru.crystals.pos.api.card.BonusBalanceEntity;
import ru.crystals.pos.api.card.CardEntity;
import ru.crystals.pos.api.card.CardHolderEntity;
import ru.crystals.pos.api.plugin.card.CardSearchResponse;
import ru.crystals.pos.api.plugin.card.CardSearchResponseStatus;
import ru.crystals.pos.spi.receipt.CardStatus;
import ru.crystals.pos.spi.receipt.CardType;
import ru.other.company.card.service.provider.xml.ObjectFactory;
import ru.other.company.card.service.provider.xml.XmlExampleAbstractCard;
import ru.other.company.card.service.provider.xml.XmlExampleCardStatus;
import ru.other.company.card.service.provider.xml.XmlExampleCards;
import ru.other.company.card.service.provider.xml.XmlExampleClient;
import ru.other.company.card.service.provider.xml.XmlExampleCoupon;
import ru.other.company.card.service.provider.xml.XmlExampleDiscountCard;

/**
 * Заглушечная реализация моста в внешнюю систему, в которой плагин будет искать карты или выполнять иные операции с ними.
 */
class CardStorage {
    /**
     * Файл, из которого плагин будет брать информацию о картах.
     */
    private static final String CARD_SOURCE_FILE = "example-cards-base.xml";

    /**
     * Хранилище карт.
     */
    private XmlExampleCards cardStorage;

    public CardStorage() {
        try (InputStream is = getClass().getClassLoader().getResourceAsStream("example-cards-base.xml")) {
            JAXBContext ctx = JAXBContext.newInstance(ObjectFactory.class);
            Unmarshaller u = ctx.createUnmarshaller();
            cardStorage = (XmlExampleCards)u.unmarshal(is);
        } catch (Exception ex) {
            throw new RuntimeException("Failed to read card storage " + CARD_SOURCE_FILE, ex);
        }
    }


    public CardSearchResponse findCardByNumber(String number) {
        if(StringUtils.isBlank(number)) {
            return null;
        }
        for(XmlExampleAbstractCard card : cardStorage.getCards()) {
            if(number.equals(card.getNumber())) {
                return createCard(card);
            }
        }
        return null;
    }

    public CardSearchResponse findCardByMobileNumber(String mobileNumber) {
        if(StringUtils.isBlank(mobileNumber)) {
            return null;
        }
        for(XmlExampleAbstractCard card : cardStorage.getCards()) {
            if(!(card instanceof XmlExampleDiscountCard)) {
                continue;
            }
            XmlExampleDiscountCard dc = (XmlExampleDiscountCard)card;
            if(dc.getHolder() == null || !mobileNumber.equals(dc.getHolder().getMobileNumber())) {
                continue;
            }
            return createCard(card);
        }
        return null;
    }

    private CardSearchResponse createCard(XmlExampleAbstractCard card) {
        CardEntity cardEntity = new CardEntity(card.getNumber(), Constants.PLUGIN_NAME);
        cardEntity.setCardStatus(createStatus(card.getStatus()));
        CardSearchResponse response = new CardSearchResponse(CardSearchResponseStatus.OK);
        if (card instanceof XmlExampleCoupon) {
            cardEntity.setCardType(CardType.COUPON);
        }

        if (card instanceof XmlExampleDiscountCard) {
            XmlExampleDiscountCard discountCard = (XmlExampleDiscountCard) card;
            cardEntity.setCardType(CardType.EXTERNAL);

            // владелец карты:
            if (discountCard.getHolder() != null) {
                XmlExampleClient client = discountCard.getHolder();
                CardHolderEntity cardHolder = new CardHolderEntity(client.getId(), client.getFirstName(), client.getLastName(), client.getMiddleName());
                cardEntity.setCardHolder(cardHolder);
            }

            // бонусный баланс
            if (discountCard.getBonusBalance() != null) {
                cardEntity.setBonusBalance(new BonusBalanceEntity(discountCard.getBonusBalance()));
            }

            // фишечный баланс
            if (discountCard.getTokensBalance() != null) {
                BonusBalanceEntity tokensBalance = new BonusBalanceEntity(BigDecimal.valueOf(discountCard.getTokensBalance()));
                tokensBalance.setMultiplier(BigDecimal.ONE);
                tokensBalance.setBalanceType(BalanceType.TOKENS);
                cardEntity.setTokensBalance(tokensBalance);
            }

            // сообщения кассиру
            if (discountCard.getPromoText() != null) {
                response.addСashierMessage(discountCard.getPromoText());
            }
        }
        response.setCard(cardEntity);
        return response;
    }

    private CardStatus createStatus(XmlExampleCardStatus status) {
        if (status == null) {
            return CardStatus.ACTIVE;
        }
        switch (status) {
            case USED:
                return CardStatus.USED;
            case BLOCKED:
                return CardStatus.BLOCKED;
            case ACTIVE:
            default:
                return CardStatus.ACTIVE;
        }
    }
}
