package ru.other.company.loy.service.provider;

import ru.crystals.pos.spi.IntegrationProperties;

/**
 * Инкапсулирует в себе способ чтения и получения настроек внешней системы, в которую входит плагин
 */
public class ServiceProperties {

    /**
     * название настройки, что хранит URL для подключения к процессингу
     */
    private static final String PROPERTY_URL = "primary.calc.url";

    /**
     * название настройки, что хранит таймаут подключения к процессингу
     */
    private static final String PROPERTY_CONNECTION_TIMEOUT = "connection.timeout";

    /**
     * название настройки, что хранит время ожидания отклика от процессинга
     */
    private static final String PROPERTY_READ_TIMEOUT = "read.timeout";

    private static final int TIMEOUT_DEFAULT_MS = 5_000;

    private IntegrationProperties integrationProperties;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link ServiceProperties}
     * @param properties получалка настроек плагина и внешней системы его
     */
    public ServiceProperties(IntegrationProperties properties) {
        this.integrationProperties = properties;
    }

    /**
     * Возвращает адрес процессинга
     * @return адрес процессинга или null, если таков не был задан
     */
    public String getProcesingUrl() {
        return integrationProperties.getServiceProperties().get(PROPERTY_URL);
    }

    /**
     * Возвращает таймаут соединения.
     * @return таймаут соединения в миллисекундах. Если в настройках он задан не был, возвращается таймаут по умолчанию {@link #TIMEOUT_DEFAULT_MS}
     */
    public int getConnectionTimeout() {
        return integrationProperties.getServiceProperties().getInt(PROPERTY_CONNECTION_TIMEOUT, TIMEOUT_DEFAULT_MS);
    }

    /**
     * Возвращает таймаут чтения.
     * @return таймаут чтения в миллисекундах. Если в настройках он задан не был, возвращается таймаут по умолчанию {@link #TIMEOUT_DEFAULT_MS}
     */
    public int getReadTimeout() {
        return integrationProperties.getServiceProperties().getInt(PROPERTY_READ_TIMEOUT, TIMEOUT_DEFAULT_MS);
    }
}
