package ru.crystals.api.examples;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.PostConstruct;
import org.slf4j.Logger;
import ru.crystals.pos.api.plugin.TechProcessPlugin;
import ru.crystals.pos.api.plugin.techprocess.InterceptionContext;
import ru.crystals.pos.api.plugin.techprocess.InterceptionResult;
import ru.crystals.pos.api.plugin.techprocess.InterceptionStatus;
import ru.crystals.pos.api.plugin.techprocess.InterceptorCallback;
import ru.crystals.pos.api.ui.listener.InputListener;
import ru.crystals.pos.spi.annotation.Inject;
import ru.crystals.pos.spi.annotation.POSPlugin;
import ru.crystals.pos.spi.receipt.Receipt;
import ru.crystals.pos.spi.ui.UIForms;

/**
 * Простейший пример плагина тех. процесса<br>
 * Плагин позволяет дополнять поведение кассы.
 */
@POSPlugin(id="ru.crystals.api.example.techprocess.plugin")
public class TechProcessExample implements TechProcessPlugin {

    private static final String COUPON_NUMBER = "ru.crystals.api.example.techprocess.coupon.number";

    @Inject
    private Logger logger;

    /**
     * Интерфейс для асинхронной манипуляции с UI кассы.
     */
    @Inject
    private UIForms uiForms;

    @PostConstruct
    public void init() {
        logger.info("{} started", this.getClass());
    }

    @Override
    public void intercept(InterceptionContext context, InterceptorCallback callback) {
        switch (context.getInterceptedStage()) {
            case CALCULATION_COMPLETE:
                // Перехватываем окончание расчета скидок.
                onCalculationComplete(context, callback);
                break;
            default:
                // Остальные пропускаем.
                restoreThisStage(callback);
        }
    }

    private void onCalculationComplete(InterceptionContext context, InterceptorCallback callback) {
        if (context.getApplicableStatusSet().contains(InterceptionStatus.RETRY) && needMoreDiscount(context)) {
            // Если еще неактивирован электронный купон, отображаем диалог для кассира:
            Map<String, List<String>> choices = new HashMap<>();
            choices.put("1", Arrays.asList("Скидка на день рождения", "10%"));
            choices.put("2", Arrays.asList("Накопительная скидка", "5%"));
            uiForms.getInputForms().showSelectionForm("Выберите купон для применения", choices, new InputListener() {
                @Override
                public void eventInputComplete(String value) {
                    InterceptionResult result = new InterceptionResult();
                    logger.info("Selected coupon: {}", choices.get(value).get(0));
                    // Добавляем изменение в чек
                    result.getReceiptExtendedAttributesMap().put(COUPON_NUMBER, value);
                    // и вызываем перерасчет.
                    callback.completed(InterceptionStatus.RETRY, result);
                }

                @Override
                public void eventCanceled() {
                    logger.warn("Selection canceled");
                    // Возобновляем тех. процесс. В данном случае переход к оплате.
                    restoreThisStage(callback);
                }
            });
        } else {
            restoreThisStage(callback);
        }
    }

    private boolean needMoreDiscount(InterceptionContext context) {
        return !context.getReceipt()
                .map(Receipt::getData)
                .map(data -> data.get(COUPON_NUMBER))
                .isPresent();
    }

    private void restoreThisStage(InterceptorCallback callback) {
        callback.completed(InterceptionStatus.CONTINUE, new InterceptionResult());
    }
}
