package ru.crystals.pos.api.comm;

/**
 * Описывает сообщение, которое требуется показать кассиру или покупателю.
 * @since 0.0.46
 */
public class CommunicationMessage {
    /**
     * Тип отображаемой в сообщении иконки. В зависимости от типа и цветовой схемы кассы могут отображаться
     * одни и те же иконки для разных значений этого поля.
     */
    private IconType iconType;
    /**
     * Верхний колонутитул сообщения (шапка).
     */
    private String header;
    /**
     * Тело сообщения.
     */
    private String body;
    /**
     * Нижний колонтитул сообщения (подвал).
     */
    private String footer;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link CommunicationMessage}.
     * @param icon тип отображаемой иконки. В зависимости от типа и цветовой схемы кассы иконки могут отображаться одни и те же для разных
     *             значений этого поля.
     * @param header верхний колонтитул (шапка) сообщения.
     * @param body тело сообщения.
     * @param footer нижний колонтитул (подвал) сообщения.
     */
    public CommunicationMessage(IconType icon, String header, String body, String footer) {
        this.iconType = icon;
        this.header = header;
        this.body = body;
        this.footer = footer;
    }

    /**
     * Возвращает тип иконки, которая должна отображаться в сообщении.
     * @return тип иконки в отображаемом сообщении
     */
    public IconType getIconType() {
        return iconType;
    }

    /**
     * Устанавливает тип иконки в отображаемом сообщении.
     * @param iconType тип иконки в отображаемом сообщении.
     */
    public void setIconType(IconType iconType) {
        this.iconType = iconType;
    }

    /**
     * Возвращает текст заголовка сообщения.
     * @return текст заголовка сообщения.
     */
    public String getHeader() {
        return header;
    }

    /**
     * Устанавливает текст заголовка сообщения.
     * @param header текст заголовка сообщения.
     */
    public void setHeader(String header) {
        this.header = header;
    }

    /**
     * Возвращает тело сообщения.
     * @return тело сообщения.
     */
    public String getBody() {
        return body;
    }

    /**
     * Устанавливает тело сообщения.
     * @param body тело сообщения.
     */
    public void setBody(String body) {
        this.body = body;
    }

    /**
     * Возвращает текст нижнего колонтитула сообщения.
     * @return текст нижнего колонтитула сообщения.
     */
    public String getFooter() {
        return footer;
    }

    /**
     * Устанавливает текст нижнего колонтитула сообщения.
     * @param footer текст нижнего колонтитула сообщения.
     */
    public void setFooter(String footer) {
        this.footer = footer;
    }

    @Override
    public String toString() {
        return "CommunicationMessage{" +
                "iconType=" + iconType +
                ", header='" + header + '\'' +
                ", body='" + body + '\'' +
                ", footer='" + footer + '\'' +
                '}';
    }
}
