package ru.crystals.pos.spi.equipment;

import ru.crystals.pos.api.ext.loyal.dto.Slip;
import ru.crystals.pos.spi.Injectable;

/**
 * Средство для печати {@link Slip сервисных документов}.
 */
public interface SetApiPrinter extends Injectable {
    /**
     * Константа, означающая, что принтер не подключен или не выдаёт информацию о ширине своей чековой ленты.
     * @since 0.0.40
     * @see #getPaperWidth() 
     */
    int PAPER_WIDTH_UNKNOWN = -1;
    /**
     * Распечатает указанный документ на принтере чеков.
     *
     * @param document документ, что надо распечатать
     * @throws SetApiPrinterException в случае возникновения ошибок при печати; {@link SetApiPrinterException#getMessage() текст}
     * содержит локализованное описание ошибки ("Открыта крышка ФР", "Закончилась чековая бумага", "Фатальная ошибка ККМ", и проч.)
     */
    void print(Slip document) throws SetApiPrinterException;

    /**
     * Получает ширину чековой ленты в символах.<br>
     * Это значение ориентировочное, настоящее значение может изменяться со шрифтом печатаемого текста.
     * @return ширина чековой ленты в символах, {@link #PAPER_WIDTH_UNKNOWN}, если она не может быть установлена.
     * @since 0.0.40
     */
    default int getPaperWidth() {
        return PAPER_WIDTH_UNKNOWN;
    }
}