package ru.crystals.pos.spi.receipt;

import java.util.Date;
import java.util.Set;

/**
 * Сущность, описывающая владельца карты
 */
public interface CardHolder {

    /**
     * Получить идентификатор владельца карты
     *
     * @return идентификатор
     */
    String getId();

    /**
     * Получить имя владельца карты
     *
     * @return имя
     */
    String getFirstName();

    /**
     * Получить фамилию владельца карты
     *
     * @return фамилия
     */
    String getLastName();

    /**
     * Получить отчество владельца карты
     *
     * @return отчество
     */
    String getMiddleName();

    /**
     * Адрес владельца карты
     *
     * @return адрес
     * @since 0.0.65
     */
    Address getClientAddress();

    /**
     * Номер телефона
     *
     * @return номер телефона
     * @since 0.0.65
     */
    String getPhone();

    /**
     * Email
     *
     * @return Email
     * @since 0.0.65
     */
    String getEmail();

    /**
     * Дата рождения
     *
     * @return дата рождения
     * @since 0.0.65
     */
    Date getBirthDate();

    /**
     * Пол
     *
     * @return пол
     * @since 0.0.65
     */
    Sex getSex();

    /**
     * Женат/замужем?
     *
     * @return женат/замужем?
     * @since 0.0.65
     */
    Boolean getMarital();

    /**
     * Признак заполненности анкеты
     *
     * @return признак заполненности анкеты
     * @since 0.0.65
     */
    boolean isCompleted();

    /**
     * Способы, которыми необходимо оповестить клиента о совершенной покупке
     *
     * @return способы, которыми необходимо оповестить клиента о совершенной покупке
     * @since 0.0.65
     */
    Set<ReceiptFeedbackType> getReceiptFeedbackTypes();
}
