package ru.crystals.pos.spi.receipt;

import java.math.BigDecimal;
import ru.crystals.pos.spi.GoodsType;

/**
 * Сущность, описывающая товар (в чековой позиции).
 *
 * @author aperevozchikov
 */
public interface Merchandise {

    /**
     * Вернет Артикул (уникальный идентификатор) товара
     *
     * @return артикул товара
     */
    String getMarking();

    /**
     * Вернет Название товара
     *
     * @return Название товара
     */
    String getName();

    /**
     * Вернет Код производителя
     *
     * @return Код производителя
     */
    String getManufacturer();

    /**
     * Вернет Код страны-производителя
     *
     * @return Код страны-производителя
     */
    String getCountry();

    /**
     * Вернет цену товара
     *
     * @return цена товара
     */
    BigDecimal getPrice();

    /**
     * Вернет штрихкод товара
     * @return штрихкод
     */
    String getBarcode();

    /**
     * Вернет ставку НДС в процентах
     * @return значение НДС
     */
    float getNds();

    /**
     * Возвращает тип товара.
     * @return тип товара.
     * @since 0.0.46
     */
    default GoodsType getGoodsType() { return GoodsType.PIECE; }

    /**
     * Возвращает идентификатор товарной группы, которой принадлежит товар.<br>
     * Товарная группа это набор товаров, объединенных каким-то признаком.
     * @return идентификатор товрной группы, которой прнадлежит товар или null если такого нет. Это идентификатор из справочника товарных групп SetRetail10.
     * @since 0.0.46
     */
    String getGroupCode();

    /**
     * Вернет флаг-признак, указывающий можно ли давать скидку на данный товар.
     *
     * @return {@code false}, если запрещен расчет скидок на данный товар
     * @since 0.0.68
     */
    default boolean isDiscountable() {
        return true;
    }
}
