package ru.crystals.pos.spi.receipt;

import ru.crystals.pos.spi.annotation.POSPlugin;

import java.math.BigDecimal;
import java.util.Map;

/**
 * Интерфейс для получения информации о проведенных/отмененных в чеке платежах.
 * @since 0.0.45
 */
public interface ProcessedPayment {

    /**
     * Вернет id типа оплаты (плагина) создавшего эту оплату.
     * @return строковый идентификатор типа оплата
     * @see POSPlugin#id()
     */
    String getPluginId();

    /**
     * Позволяет определить платеж отмененный, либо проведенный.
     *
     * @return <tt>true</tt> если это отмененный платеж<br>
     *         <tt>false</tt> в противном случае
     */
    boolean isAnnulling();

    /**
     * Сумма оплаты
     *
     * @return сумма с двумя знаками после запятой (scale = 2)
     */
    BigDecimal getSum();

    /**
     * Дополнительные данные транзакции выполненной оплаты.
     *
     * @return коллекция ключей и значений
     */
    Map<String, String> getData();

    /**
     * Если оплата была произведена с использованием карты, возвращает номер карты.
     * @return номер карты или null, если карта не использовалась при оплате.
     * @since 0.0.46
     */
    default String getCardNumber() {
        return null;
    }

}