package ru.crystals.pos.spi.ui.payment;

import java.math.BigDecimal;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Модель данных для формы, отображающей ввод суммы к оплате/возврату.
 */
public class SumToPayFormParameters {

    private String caption;
    private String inputHint;
    private Receipt receipt;
    private BigDecimal defaultSum;
    private BigDecimal minSum;
    private BigDecimal maxSum;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link SumToPayFormParameters}.
     * 
     * @param caption
     *            заголовок формы
     * @param receipt
     *            текущий чек
     */
    public SumToPayFormParameters(String caption, Receipt receipt) {
        this.caption = caption;
        this.receipt = receipt;
    }
    
    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link SumToPayFormParameters}.
     * 
     * @param caption
     *            заголовок формы
     * @param inputHint
     *            текстовая подсказка, в поле ввода суммы           
     * @param receipt
     *            текущий чек
     * @param defaultSum
     *            сумма предлагаемая по умолчанию в поле ввода
     */
    public SumToPayFormParameters(String caption, String inputHint, Receipt receipt, BigDecimal defaultSum) {
        this.caption = caption;
        this.inputHint = inputHint;
        this.receipt = receipt;
        this.defaultSum = defaultSum;
    }

    /**
     * Получить текст заголовка формы
     * 
     * @return текст заголовка формы
     */
    public String getCaption() {
        return caption;
    }

    /**
     * Установить текст заголовка формы
     * 
     * @param caption
     *            текст заголовка формы
     */
    public void setCaption(String caption) {
        this.caption = caption;
    }

    /**
     * Возвращает текстовую подсказку, которая отображается в поле ввода.
     * 
     * @return текст подсказки.
     */
    public String getInputHint() {
        return inputHint;
    }

    /**
     * Устанавливает текстовую подсказку, которая отображается в поле ввода.
     * 
     * @param inputHint
     *            текст подсказки
     */
    public void setInputHint(String inputHint) {
        this.inputHint = inputHint;
    }

    /**
     * Получить текущий чек, в котором выполняется оплата, возврат.
     *  
     * @return чек
     */
    public Receipt getReceipt() {
        return receipt;
    }

    /**
     * Установить текущий чек, в котором выполняется оплата, возврат.
     * 
     * @param receipt чек
     */
    public void setReceipt(Receipt receipt) {
        this.receipt = receipt;
    }

    /**
     * Получить сумму предлагаемую по умолчанию.
     * 
     * @return сумма по умолчанию
     */
    public BigDecimal getDefaultSum() {
        return defaultSum;
    }

    /**
     * Установить сумму предлагаемую по умолчанию.
     * 
     * @param defaultSum
     *            сумма по умолчанию
     */
    public void setDefaultSum(BigDecimal defaultSum) {
        this.defaultSum = defaultSum;
    }

    /**
     * Получить дополнительное ограничение минимальной суммы.
     * 
     * @return минимальная сумма
     */
    public BigDecimal getMinSum() {
        return minSum;
    }

    /**
     * Установить дополнительное ограничение минимальной суммы.
     * 
     * @param minSum
     *            минимальная сумма
     */
    public void setMinSum(BigDecimal minSum) {
        this.minSum = minSum;
    }

    /**
     * Получить дополнительное ограничение минимальной суммы.
     * 
     * @return минимальная сумма
     */
    public BigDecimal getMaxSum() {
        return maxSum;
    }

    /**
     * Установить дополнительное ограничение максимальной суммы.
     * 
     * @param maxSum
     *            максимальная сумма
     */
    public void setMaxSum(BigDecimal maxSum) {
        this.maxSum = maxSum;
    }

    @Override
    public String toString() {
        return "SumToPayFormParameters{" +
                "caption='" + caption + '\'' +
                ", inputHint='" + inputHint + '\'' +
                ", receipt=" + receipt +
                ", defaultSum=" + defaultSum +
                ", minSum=" + minSum +
                ", maxSum=" + maxSum +
                '}';
    }
}
